import React, { Component } from 'react'
import BaseComponent from '../BaseComponent';
import './index.scss'

export default class BusinessCard extends BaseComponent {
  constructor (props) {
    super(props)
    this.businessRef = React.createRef()
    this.tipRef = React.createRef()
  }

  componentDidMount = () => {
    this.props.onDidMount && this.props.onDidMount(this.businessRef.current.offsetHeight)
  }

  onMouseLeaveHandler = () => {
    this.tipRef.current.style.display = 'none'
  }

  onMouseEnterHandler = (txt, e) => {
    let target = e.currentTarget
    const w = target.offsetWidth, h = target.offsetHeight
    let t = target.offsetTop, l = target.offsetLeft
    //从目标元素开始向外遍历，累加top和left值
    while (target.offsetParent) {
      target = target.offsetParent
      t += target.offsetTop
      l += target.offsetLeft
    }
    this.tipRef.current.children[0].innerHTML = txt
    this.tipRef.current.style.display = 'inline'
    this.tipRef.current.style.top = `${t - h - 10 - this.props.containerScrollTop}px`
    this.tipRef.current.style.left = `${l}px`
  }

  onClickHandler = () => {
    if(!this.props.active) {
      this.props.onClick && this.props.onClick(this.props.dataSource)
    }
  }

  onCheckClickHandler = (e) => {
    e.stopPropagation()
    this.props.onCheckClick && this.props.onCheckClick(this.props.dataSource)
  }

  render () {
    const dataSource = this.props.dataSource
    const status = dataSource.statusList.find(stu => {return stu['value'] === dataSource.status})
    return <div ref={this.businessRef} className={`business-container ${this.props.showCheckBox ? 'showbox' : 'hidebox'} ${this.props.active && 'active'}`} onClick={this.onClickHandler}>
      <div className='business-container-line'></div>
      <div className='select-box'>
        <span className={`checkbox ${this.props.isChecked ? 'checked' : ''}`} onClick={this.onCheckClickHandler} />
      </div>
      <div className='card'>
        <span className='info-tip' ref={this.tipRef}><span className='info-tip-txt'></span></span>
        <div className='person'>
          <span>
            <span className='person-name'
              onMouseEnter={this.onMouseEnterHandler.bind(this, dataSource.name)}
              onMouseLeave={this.onMouseLeaveHandler}
              >{dataSource.name}
            </span>
            <span className={`sex-${dataSource['sex']}`}/>
          </span>
          <span className={`status-${status ? status['value'] : ''}`}>{status ? status['text'] : ''}</span>
        </div>
        <div className='info'>
          {
            dataSource.info.map((info, index, arr) => {
              return <span key={index} className='info-item'
                onMouseEnter={index >= 1 ? this.onMouseEnterHandler.bind(this, info.value) : null}
                onMouseLeave={index >= 1 ? this.onMouseLeaveHandler : null}
              >
                <span className='info-txt'>
                  {info.text}
                </span>
              </span>
            })
          }     
        </div>
        <div className='subscript'>{dataSource.subscript}</div>
      </div>
    </div>
  }
}