import BaseComponent from '../../BaseComponent';
import * as React from 'react';
import {getUIList, UIItem} from './register';
import {MainContext} from "../mainContext";
import './itemConfig';
import './index.scss';

export default class Toolbar extends BaseComponent {
  private uiList: Array<UIItem> = [];
  private uiComponentList = {};
  static defaultProps = {
    toolbars: [
      'brush', 'eraser'
    ],
    setUI() {
    }
  };

  constructor(props: any) {
    super(props);
    let registerUIList = getUIList();
    this.uiList = this.props.toolbars.map((name: string) => {
      let matchUI;
      for (let ui of registerUIList) {
        if (ui.uiName === name) {
          matchUI = ui;
        }
      }
      return matchUI;
    });
    this.state = {
      crtUI: this.props.toolbars[0]
    };
  }

  componentDidMount() {
    const {crtUI} = this.state;
    this.props.setUI(this.uiComponentList[crtUI]);
  }

  setCrtUI(uiName: string) {
    this.setState({
      crtUI: uiName
    }, () => {
      this.props.setUI(this.uiComponentList[this.state.crtUI]);
    });
  }

  render() {
    const {crtUI} = this.state;
    const generageUIlist = (mainContext: any) => {
      return this.uiList.map((ui) => {
        return (
          <li key={ui.id} onClick={this.setCrtUI.bind(this, ui.uiName)}
              className={`doodle-board-toolbar-item__wrap ${crtUI === ui.uiName ? 'z-crt' : ''}`}>
            <ui.uiClass ref={(item: any) => {
              this.uiComponentList[ui.uiName] = item
            }} mainContext={mainContext}/>
          </li>
        )
      });
    };
    return (
      <div className="doodle-board-toolbar">
        <ul className="doodle-board-toolbar-list clearfix">
          <MainContext.Consumer>
            {(context) => {
              return generageUIlist(context.mainContext)
            }}
          </MainContext.Consumer>
        </ul>
      </div>
    );
  }
}
