class UndoUtil {
  private stack: Array<any>;
  private index: number;
  private maxLength: number;
  private initData: any;

  constructor(initData: any, maxLength: number = 15) {
    this.stack = [];
    this.maxLength = maxLength;
    this.initData = initData;
    this.stack.push(initData);
    this.index = 0;
  }

  _truncate() {
    while (this.stack.length > this.maxLength) {
      this.stack.shift();
    }
  }

  clear() {
    this.stack = [this.initData];
    this.index = 0;
  }

  save(data: any) {
    this._truncate();
    this.index = Math.min(this.index, this.count());
    this.stack = this.stack.slice(0, this.index + 1);
    this.index++;
    this.stack.push(data);
  }

  current() {
    return this.stack[this.index];
  }

  undo() {
    if (this.canUndo()) {
      return this.stack[--this.index];
    }
    return null;
  }

  redo() {
    if (this.canRedo()) {
      return this.stack[++this.index];
    }
    return null;
  }

  canRedo() {
    return this.index < this.count();
  }

  canUndo() {
    return this.index > 0;
  }

  count() {
    return this.stack.length - 1;
  }
}

export default UndoUtil;
