import React, { Component } from 'react';
import PropTypes from 'prop-types';
import BaseComponent from '../BaseComponent';
import AntdModal from '../antd-modal';
import ImagePreviewModal from '../imagepreview-modal';
import { calcuteFileSize } from '../util/util';
import '../../assets/symbol';
import './index.scss';

const MAX_FILE_SIZE = 10 * 1024 * 1024;
export default class FeedbackModal extends BaseComponent{
  static defaultProps = {
    elinkId: null,
    visible: false,
    cancel: () => {
    },
    submit: () => {
    }
  };
  textAreaEle;  // textArea元素
  fileIptEle; // 文件选择框
  doodleBoardComponent; // 涂鸦板实例
  crtPreviewImgIndex; // 当前浏览的图片

  constructor(props) {
    super(props);
    this.onInput = this.onInput.bind(this);
    this.onPaste = this.onPaste.bind(this);
    this.goImgPreview = this.goImgPreview.bind(this);
    this.saveImage = this.saveImage.bind(this);
    this.cancelImage = this.cancelImage.bind(this);
    this.hideModal = this.hideModal.bind(this);
    this.chooseFile = this.chooseFile.bind(this);
    this.clickChooseFile = this.clickChooseFile.bind(this);
    this.removeScreenshots = this.removeScreenshots.bind(this);
    this.submit = this.submit.bind(this);
    this.cancel = this.cancel.bind(this);
    this.textAreaEle = null;
    this.doodleBoardComponent = null;
    this.state = {
      descText: '', // 描述内容
      screenshotsList: [], // 截屏列表
      noPassRuleFileList: [], // 没有通过校验的文件列表，用于错误弹窗
      crtScreenshots: {}, // 当前编辑的截图
      isShowPreviewModal: false // 是否显示浏览截图弹窗
    };
  }

  /**
   * desc 描述input事件
   * @param event
   */
  onInput(event) {
    this.setState({
      descText: event.target.value
    });
  }

  /**
   * 缩略图->大图
   * @param screenshots 缩略图
   * @param idx 列表index
   */
  goImgPreview(screenshots, idx) {
    this.setState({
      isShowPreviewModal: true,
      crtScreenshots: screenshots
    });
    this.crtPreviewImgIndex = idx;
  }

  /**
   * 保存图片回调，大图点击保存后的相关方法
   * @param result 具体返回数据
   */
  saveImage(result) {
    this.setState((preState) => {
      return {
        screenshotsList: preState.screenshotsList.map((screenshots, idx) => {
          if (idx === this.crtPreviewImgIndex) {
            return Object.assign({}, screenshots, {
              additionalImg: result.additionalImg,
              composeImg: result.composeImg,
              composeImgWithBlog: result.composeImgWithBlog,
              resultFile: new File([result.composeImgWithBlog], screenshots.resultFile.name, {
                lastModified: Number(new Date())
              })
            });
          }
          return screenshots;
        }),
        isShowPreviewModal: false
      };
    });
  }

  /**
   * 取消image大图
   */
  cancelImage() {
    this.setState({
      isShowPreviewModal: false
    });
  }

  /**
   * 隐藏弹窗
   */
  hideModal() {
    this.setState({
      visible: false
    });
  }

  /**
   * 点击上传按钮代理
   */
  clickChooseFile() {
    this.fileIptEle.click();
  }

  /**
   * 添加截图方法
   * @param fileList 文件列表
   * @return {Promise<void>}
   * @private
   */
  async _addScreenshotsList(fileList) {
    const readerPromiseList = [];
    // 遍历文件列表
    for (let file of fileList) {
      if (/image/i.test(file.type)) {
        // 如果是图片，获取文件内容
        readerPromiseList.push(new Promise((resolve) => {
          const fileReader = new FileReader();
          fileReader.readAsDataURL(file);
          fileReader.onload = function () {
            // promise resolve
            resolve({
              resultFile: file,
              originImg: this.result
            });
          };
        }));
      }
    }
    // 获取所有文件内容
    const filesData = await Promise.all(readerPromiseList);
    // 组装对象
    const addedScreenshotsList = filesData.map(({ originImg, resultFile }) => {
      return {
        originImg: originImg,
        additionalImg: null,
        composeImg: null,
        composeImgWithBlog: null,
        resultFile: resultFile
      };
    });
    this.setState(({ screenshotsList }) => {
      return {
        screenshotsList: screenshotsList.concat(addedScreenshotsList)
      };
    }, () => {
      const { noPassRuleFileList } = this.state;
      // 如果存在未通过规则文件列表 弹出提示窗
      if (noPassRuleFileList.length > 0) {
        AntdModal.info({
          title: '提示',
          className: 'feedback-error-modal',
          width: 500,
          zIndex: 1103,
          content: (<ul>
            {noPassRuleFileList.map((fileObj, idx) => (
              <li key={idx}>
                {fileObj.file.name}（{calcuteFileSize(fileObj.file.size)}）— &nbsp;{fileObj.msg}
              </li>
            ))}
          </ul>),
          okText: '我知道了',
          onOk: () => {
            this.setState({
              noPassRuleFileList: []
            });
          }
        });
      }
    });
  }

  _getComplyWithTheRulesFile(fileList) {
    let canUploadFilesLength = 5 - this.state.screenshotsList.length;
    const resultFileList = [];
    // 未通过校验的文件列表
    const noPassRuleFileList = [];
    // 最多5张的限制
    let i = 0;
    while (i < fileList.length) {
      const file = fileList[i];
      if (canUploadFilesLength === 0) {
        // 设置超过超过限制的文件到失败列表列表
        noPassRuleFileList.push({
          file,
          msg: '超出文件上传个数限制'
        });
      } else if (file.size > MAX_FILE_SIZE) {
        // 设置超过大小的文件到失败列表列表
        noPassRuleFileList.push({
          file,
          msg: '文件大小超过上限'
        });
      } else {
        resultFileList.push(file);
        canUploadFilesLength--;
      }
      i++;
    }
    this.setState({
      noPassRuleFileList
    });
    return resultFileList;
  }

  onPaste(e) {
    // 获取剪切板的数据
    const { clipboardData } = e;
    // 添加文件
    this._addScreenshotsList(this._getComplyWithTheRulesFile(clipboardData.files));
  }

  chooseFile(e) {
    this._addScreenshotsList(this._getComplyWithTheRulesFile(e.target.files));
    e.target.value = '';
  }

  /**
   * 移除截图
   * @param event 点击事件
   * @param removeIdx 移除的索引
   */
  removeScreenshots(event, removeIdx) {
    event.stopPropagation();
    this.setState(({ screenshotsList }) => {
      return {
        screenshotsList: screenshotsList.filter((itm, idx) => idx !== removeIdx)
      };
    });
  }

  __updateFileWithQuene() {
    const { screenshotsList } = this.state;
    const promiseQuene = [];
    for (let screenshots of screenshotsList) {
      const formData = new FormData();
      formData.append('elinkId', this.props.elinkId);
      formData.append('uploadType', 92);
      formData.append('name', screenshots.resultFile.name);
      formData.append('FileData', screenshots.resultFile);
      promiseQuene.push(
        fetch('/Elink/UploadFile/Save', {
          method: 'POST',
          body: formData
        }).then((resp) => {
          return resp.json();
        })
      );
    }
    return promiseQuene;
  }

  /**
   * 调用props的submit,同时将descText,imgPath返回
   * @return {Promise<void>}
   */
  async submit() {
    const resps = await Promise.all(this.__updateFileWithQuene());
    let imgPath = resps.reduce((pre, crt) => [...pre, ...crt.DfsPath], []);
    this.props.submit({
      descText: this.state.descText,
      imgPath
    });
    // 重置数据
    this.setState({
      descText: '',
      screenshotsList: [],
      noPassRuleFileList: [],
      crtScreenshots: {},
      isShowPreviewModal: false
    });
  }

  cancel() {
    this.setState({
      descText: '',
      screenshotsList: [],
      noPassRuleFileList: [],
      crtScreenshots: {},
      isShowPreviewModal: false
    }, () => {
      this.props.cancel();
    });
  }

  _getModalFooter() {
    const { descText } = this.state;
    return (<div className="feedback-modal-footer">
      <button className="oper__btn submit__btn" disabled={!descText} onClick={this.submit}>提交</button>
      <button className="oper__btn cancel__btn" onClick={this.cancel}>取消
      </button>
    </div>);
  }

  render() {
    const { screenshotsList, isShowPreviewModal, crtScreenshots, descText } = this.state;
    const { visible } = this.props;
    return (
      <div className="feedback-modal">
        <AntdModal
          title="产品问题反馈"
          visible={visible}
          width="720px"
          wrapClassName="feedback-modal"
          footer={this._getModalFooter()}
          onCancel={this.cancel}
          zIndex={1101}>
          <div className="feedback-modal-content">
            <div className="left-content">
              <img src="//stnew03.beisen.com/ux/tms-recruit/release/app/images/tucao.png"/>
            </div>
            <div className="right-content">
              <div>
                <label className="desc"><span className="symbol">*</span>问题描述：</label>
              </div>
              <div>
                <textarea
                  ref={(ele) => this.textAreaEle = ele} className="desc__textarea"
                  placeholder="写下你对招聘系统的疑问或者建议，除了上传图片，也可以尝试粘贴产品问题截图进来哦~"
                  maxLength="500" onChange={this.onInput} onPaste={this.onPaste} value={descText}/>
                <p className="desc__textarea-tip">字数限制500字以内</p>
              </div>
              {screenshotsList.length < 5 
                ? <div>
                    <button className="screenshots__btn-upload" onClick={this.clickChooseFile}>上传</button>
                    <span className="screenshots__btn-upload-tip">（最多可以上传5个图片，每个大小不超过10M）</span>
                  </div>
                : 
                null}
              <ul className="screenshots-list clearfix">
                {screenshotsList.map((item, idx) => {
                  return (
                    <li className="screenshots-item" key={idx} onClick={() => {
                      this.goImgPreview(item, idx);
                    }}>
                      <svg className="icon screenshots_close" aria-hidden="true" onClick={(e) => {
                        this.removeScreenshots(e, idx);
                      }}>
                        <use xlinkHref="#icon-guanbi"/>
                      </svg>
                      <img className="screenshots__img" src={item.composeImg ? item.composeImg : item.originImg}/>
                      <p className="screenshots__img_name">
                        {item.resultFile.name}
                      </p>
                    </li>
                  );
                })}
              </ul>
              <input
                className="screenshots__ipt-upload"
                type="file" multiple="multiple" accept=".jpg,.png,.jpeg,.bmp,.gif,svg" onChange={this.chooseFile}
                ref={(ele) => {
                  this.fileIptEle = ele;
                }}/>
            </div>
          </div>
        </AntdModal>
        <ImagePreviewModal
          onSave={this.saveImage}
          onCancel={this.cancelImage}
          visible={isShowPreviewModal}
          backdropImg={crtScreenshots.originImg}
          initBoardImg={crtScreenshots.additionalImg}
        />
      </div>
    );
  }
}

FeedbackModal.propTypes = {
  elinkId: PropTypes.string.isRequired, // 上传图片重要的elinkId,
  visible: PropTypes.bool.isRequired, // 弹窗展示
  submit: PropTypes.func.isRequired, // 提交回调
  cancel: PropTypes.func.isRequired // 取消回调
};
