import React,{ Component } from 'react';
import BaseComponent from '../BaseComponent';
import FormComponentMap from './formComponentMap';
import * as formVerify from './formVerify';
import omit from 'lodash.omit';
require('./form.scss');

// 当前表单仅在应聘者详情使用
export default class extends Component {
    constructor(props) {
        super(props);
        this.handleExEdit = this.handleExEdit.bind(this);
        this.handleExBack = this.handleExBack.bind(this);
        this.handleSubmit = this.handleSubmit.bind(this);

        this.state = {
            dataSource: props.dataSource,
            isEdit: false,
            isUnfold: localStorage.isUnfoldBasicInfo === 'true' ? true : false
        };
        this.dataSource = this.copyDataSource(this.state.dataSource)
        this.errorMessages = [];
    }

    componentWillReceiveProps(nextProps) {
        if(this.state.dataSource !== nextProps.dataSource) {
            const dataSoucre = this.copyDataSource(nextProps.dataSource)
            this.setState({dataSource: dataSoucre});
        }
    }

    copyDataSource (dataSource) {
        let returnDataSource = []
        dataSource.map((data,index) => {
            let ele = Object.assign({} , data)
            let arr = []
            if (ele.hasOwnProperty('biz_data')) {
                ele['biz_data'].forEach(biz => {
                    arr.push(Object.assign({}, biz))
                })
                ele['biz_data'] = arr
            }
            returnDataSource.push(ele)
        })
        return returnDataSource
    }
    /**
    * 执行编辑按钮
    */
    handleExEdit() {
        this.setState({isEdit: true})
    }
    /**
    * 执行返回按钮
    */
    handleExBack() {
        this.dataSource = this.copyDataSource(this.props.dataSource)
        this.errorMessages = [];
        this.setState({dataSource: this.dataSource, isEdit: false});
    }
    /**
    * 执行保存按钮
    */
    handleSubmit() {
        for (let i = 0; i < this.dataSource.length; i++) {
            let item = this.dataSource[i];
            var rule = item.rule;
            if (rule && item.visible) {
                if (item.cmp_type === 'input-phone') {
                    rule = [{
                        reg: `${item.cmp_type}Phone`,
                        message: '请填写正确的手机号码'
                    }]
                }
                const message = formVerify.verify(item.value, rule);
                this.dataSource[i]['errorMessage'] = message ? message : '';
                if (message) {
                    this.setState({
                        dataSource: this.dataSource
                    });
                    return;
                }
            }
        }
        this.props.submitForm && this.props.submitForm(this.state.dataSource);
        this.setState({isEdit: false});
    }

    changeHandler(index, val, e) {
        let text, value = '';
        if(typeof val  === 'string') {
            text = value = val
            let rule = this.dataSource[index]['rule'];
            // 手机号特殊处理，手机类型
            if (index === 3 && typeof val === 'string') {
                rule = [{
                    reg: `${e}Phone`,
                    message: '请填写正确的手机号码'
                }];
            }
            const message = formVerify.verify(value, rule);
            const point = this.errorMessages.indexOf(index);
            if(message) {
                this.dataSource[index]['errorMessage'] = message;
                point === -1 && this.errorMessages.push(index);
            }else {
                this.dataSource[index]['errorMessage'] = '';
                point > -1 && this.errorMessages.splice(point,1);
            }
            this.props.formErrorNotify && this.props.formErrorNotify(this.errorMessages.length !== 0);
        }else {
            text = val['text'];
            value = val['value'];
            if(this.dataSource[index]['biz_data']) {
                this.dataSource[index]['biz_data'].forEach(item => {
                    item.selected = (item.value === val['value']);
                });
            }
        }
        this.dataSource[index][this.dataSource[index]['filed']] = text;
        this.dataSource[index].text = text;
        this.dataSource[index].value = value;
        // 手机号特殊处理，手机类型
        if (index === 3 && typeof val === 'string') {
            this.dataSource[index].mobileType = e;
        }
        this.setState({dataSource: this.dataSource});
    }

    expandBasicInfo = () => {
        let isUnfold = !this.state.isUnfold
        this.setState({
            isUnfold: isUnfold
        }, () => {
            localStorage.isUnfoldBasicInfo = isUnfold
            this.props.onExpand(isUnfold)
        })
    }

    render() {
        return (
            <div className='form-container'>
                <table className='content'>
                    <tbody>
                    {
                        this.state.dataSource.map((ele,index) => {
                            let arr = []
                            if (ele.hasOwnProperty('biz_data')) {
                                ele['biz_data'].forEach(biz => {
                                    arr.push(Object.assign({}, biz))
                                })
                            }
                            {/* 查看态不显示姓名字段 */}
                            if (ele.filed === 'name' && !this.state.isEdit) {
                                return
                            }
                            if(ele.visible === false) {
                                return ;
                            }
                            const FormComponent = FormComponentMap.getComponentMap(ele['cmp_type'] || 'input');
                            {/* 如果是查看态，不展开状态只展示手机和邮箱字段 */}
                            return (<tr key={index} className={`${(!this.state.isEdit && !this.state.isUnfold && index > 4) ? 'hidden' : ''}`}>
                                        <td className='filed'>{ele.fieldName}:</td>
                                        {<td id={index} className='value'>
                                            {this.state.isEdit ?
                                            <FormComponent dataSource={arr}
                                                           fieldName={'text'}
                                                           onChange={this.changeHandler.bind(this, index)}
                                                           isShowArrow={false}
                                                           disabled={ele.disabled}
                                                           errorMessage={ele.errorMessage}
                                                           text={ele.text}
                                                           value={ele.value}
                                                           {...omit(ele, ['text', 'value', 'errorMessage', 'disabled', 'fieldName', 'biz_data'])}
                                                           /> : <input className='txt' disabled='disabled' title={ele.text} value={ele.text}/>
                                            }
                                            <div className='message'>{ele.errorMessage}</div>
                                            {(this.state.isEdit && ele.filed == 'mobile' && ele.mobileType == 'oth' && !ele.errorMessage)
                                            && <div className='mobile-tip'>请在手机号前输入”00“和国家码</div>
                                            }
                                        </td>}
                                    </tr>)

                        })
                    }
                    </tbody>
                </table>
                {
                    !this.state.isEdit &&
                    <div className="expand-btn" onClick={this.expandBasicInfo}>
                        <span className={`${this.state.isUnfold ? 'fold' : 'unfold'}`}></span>
                    </div>
                }
                
            </div>
        )
    }
}
