import React, { Component } from 'react';
import BaseComponent from '../BaseComponent';
import AntdTable from 'antd/lib/table';
import Trigger from 'rc-trigger';
import placements from '&/helper/placements';
// rc-trigger样式
require('rc-trigger/assets/index.css');
// rc-table样式
require('antd/lib/table/style/css');
require('./Header.scss');

export default class extends BaseComponent {
  constructor(props) {
    super(props);
    this.addTagHandler = this.addTagHandler.bind(this);
    this.deleteTagHandler = this.deleteTagHandler.bind(this);
    this.onClickJobHandler = this.onClickJobHandler.bind(this);
    this.onClickJobListHandler = this.onClickJobListHandler.bind(this);

    this.jobList = this.props.dataSource.jobList || [];
    this.hasRenderedTag = false
    this.state = {
      isShowRight: this.props.isShowRight,
      tagList: this.props.dataSource.tagList || [],
      stroreDbCount: this.props.dataSource.stroreDbCount || 0,
      storeDbInfos: this.props.dataSource.storeDbInfos || [],
      jobInfos: this.props.dataSource.jobInfos || [],
      jobCountTableVisible: false,
      talentCountTableVisible: false,
      tagShowNum: this.props.dataSource.tagList.length,
    };
    this.jobActiveIndex = this.jobList.findIndex((job) => {
      return job['jobId'] === this.props.dataSource.jobId;
    });
    this.jobActiveIndex = this.jobActiveIndex !== -1 ? this.jobActiveIndex : 0;
    this.jobliShow = false;
    this.isHiddenStoreDbInfos = true;
    this.isHiddenJobInfos = true;
    this.clickFlag = false;

    document.addEventListener('click', (e) => {
      if (this.jobliShow && !!this.joblistDom.className.match('active')) {
        this.jobliShow = false;
        this.joblistDom.className = 'joblist';
        this.arrowIcon.className = 'arrow-expand';
      }
      const className = e.target.className;
      if (className !== 'talent-num' && className !== 'talent' && className !== 'storeDbInfoHead' && className !== 'storeDbInfoBody' && this.isHiddenStoreDbInfos) {
        this.refs.storeDbInfos && (this.refs.storeDbInfos.className = 'storeDbInfos hidden');
      }
      if (className !== 'num' && className !== 'jobInfos' && className !== 'jobInfoHead' && className !== 'jobInfoBody' && this.isHiddenJobInfos) {
        this.refs.jobInfos && (this.refs.jobInfos.className = 'jobInfos hidden');
      }
      this.isHiddenStoreDbInfos = true;
      this.isHiddenJobInfos = true;
    });
  }

  componentWillReceiveProps(nextProps) {
    this.jobActiveIndex = this.jobList.findIndex((job) => {
      return job['jobId'] === nextProps.dataSource.jobId;
    }) || 0;
    this.jobActiveIndex = this.jobActiveIndex !== -1 ? this.jobActiveIndex : 0;
    this.setState({
      tagList: nextProps.dataSource.tagList || [],
      stroreDbCount: nextProps.dataSource.stroreDbCount,
      storeDbInfos: nextProps.dataSource.storeDbInfos || [],
      jobInfos: nextProps.dataSource.jobInfos || [],
      isShowRight: nextProps.isShowRight,
      tagShowNum: this.state.tagShowNum || nextProps.dataSource.tagList.length // 展示的标签个数
    });
    this.clickFlag = false;
  }

  componentWillUnmount() {
    document.removeEventListener('click', () => {}, false);
  }

  onClickJobHandler(e) {
    e.preventDefault();
    e.stopPropagation();
    this.props.changeJobHandler && this.props.changeJobHandler(this.jobList[parseInt(e.target.getAttribute('index'))]);
  }

  onClickJobListHandler(e) {
    e.preventDefault();
    e.stopPropagation();
    if (this.jobList.length > 1 && !this.jobliShow) {
      this.joblistDom.className = 'joblist active';
      this.arrowIcon.className = 'arrow-expand arrow-unfold';
      setTimeout(() => {
        this.jobliShow = true;
      }, 100);
    }
  }

  addTagHandler(e) {
    e.preventDefault();
    e.stopPropagation();
    if (this.clickFlag) {
      return false;
    }
    this.clickFlag = true;
    // 重新计算显示标签个数
    this.hasRenderedTag = false
    this.props.addTagHandler && this.props.addTagHandler();
  }

  deleteTagHandler(e) {
    e.preventDefault();
    e.stopPropagation();
    if (e.target.className.indexOf('disable') > -1 || this.clickFlag) {
      return;
    }
    this.clickFlag = true;
    // 重新计算显示标签个数
    this.hasRenderedTag = false
    this.props.deleteTagHandler && this.props.deleteTagHandler(this.state.tagList[parseInt(e.currentTarget.getAttribute('index'))]);
  }
  /**
   * 重复简历图标点击
   */
  onClickRepeat = (e) => {
    e.preventDefault();
    e.stopPropagation();
    this.props.onClickRepeat && this.props.onClickRepeat(this.jobList[this.jobActiveIndex]);
  }

  // onClickJobNumHandler = (e) => {
  //   if (this.refs.jobInfos.className === 'jobInfos' || this.props.dataSource.jobCount <= 0) {
  //     this.refs.jobInfos.className = 'jobInfos hidden';
  //     return;
  //   }
  //   this.refs.jobInfos.className = 'jobInfos';
  //   this.isHiddenJobInfos = true;
  //   this.props.onClickJobNumHandler && this.props.onClickJobNumHandler();
  // }

  // onClickTalentHandler = (e) => {
  //   if (this.refs.storeDbInfos.className === 'storeDbInfos' || this.state.stroreDbCount <= 0) {
  //     this.refs.storeDbInfos.className = 'storeDbInfos hidden';
  //     return;
  //   }
  //   this.refs.storeDbInfos.className = 'storeDbInfos';
  //   this.isHiddenStoreDbInfos = true;
  //   this.props.onClickTalentHandler && this.props.onClickTalentHandler();
  // }

  removeTalentHandler = (talent, e) => {
    e.preventDefault();
    e.stopPropagation();
    this.props.removeTalentHandler && this.props.removeTalentHandler(talent);
    if (this.state.storeDbInfos.length === 1) {
      this.setState({
        talentCountTableVisible: false
      });
    }
  }

  formatJobTableData = (res) => {
    return res.map((i, index) => {
      return {
        ..._.omit(i, ['PhaseName', 'StatusName']),
        PhaseAndStatusName: i.PhaseName + '-' + i.StatusName,
        JobNameCode:{
          JobName: i.JobName,
          JobCode: i.JobCode
        },
        HrDuty: {
          HrDutyEmail: i.HrDutyEmail,
          HrDutyMobile: i.HrDutyMobile,
          HrDutyName: i.HrDutyName
        },
        key: index
      };
    });
  }

  getJobColumns = () => {
    let res = [
      {
        title: '需求部门',
        dataIndex: 'DepartmentName',
        key: 'DepartmentName',
        width: 80
      },
      {
        title: '申请职位',
        dataIndex: 'JobNameCode',
        key: 'JobNameCode',
        width: 120,
        render: record => {
          return [<div key="JobName">{record.JobName}</div>, <div key="JobCode">（{record.JobCode}）</div>];
        }
      },
      {
        title: '阶段-状态',
        dataIndex: 'PhaseAndStatusName',
        key: 'PhaseAndStatusName',
        width: 110
      },
      {
        title: '申请时间',
        dataIndex: 'ApplyDate',
        key: 'ApplyDate',
        width: 90
      },
      {
        title: '申请渠道',
        dataIndex: 'ChannelName',
        key: 'ChannelName',
        width: 100
      }, {
        title: '职位负责人',
        dataIndex: 'HrDuty',
        key: 'HrDuty',
        width: 220,
        render: record => {
          return [<div key="HrDutyName">{record.HrDutyName}</div>, <div key="HrDutyEmail">{record.HrDutyEmail}</div>, <div key="HrDutyMobile">{record.HrDutyMobile}</div>];
        }
      }, {
        title: '职位状态',
        dataIndex: 'JobStatus',
        key: 'JobStatus',
        width: 100,
        render: data => {
          return data || '-';
        }
      }
    ];

    if (this.props.isElink) {
      // res.pop();
      let elinkRes = res.filter(item => {
        return item.key !== 'HrDuty'
      })
      return elinkRes;
    }
    return res;
  }

  getJobTableProps = () => {
    const { jobInfos } = this.state;
    return {
      className: 'table-module',
      size: 'small',
      dataSource: this.formatJobTableData(jobInfos),
      columns: this.getJobColumns(),
      pagination: false,
      scroll: { y: 160 }
    };
  }

  getJobPopupElement = () => {
    return (
      <div className="table-popup-wrapper jobtips-popup-wrapper">
        <div className="table-popup__arrow" ref={e => {
          this.arrowRef = e;
        }}
        />
        <AntdTable {...this.getJobTableProps()} />
      </div>
    );
  }

  handleJobCountVisibleChange = (visible) => {
    if (this.props.dataSource.jobCount <= 0) {
      return;
    }
    this.setState({ jobCountTableVisible: visible });
    this.props.onClickJobNumHandler && this.props.onClickJobNumHandler();
  }

  getTalentColumns = () => {
    let res = [
      {
        title: '人才库',
        dataIndex: 'StoreDbName',
        key: 'StoreDbName',
        width: 120
      },
      {
        title: '储备时间',
        dataIndex: 'CreateDate',
        key: 'CreateDate',
        width: 90
      },
      {
        title: '储备人',
        dataIndex: 'CreateByName',
        key: 'CreateByName',
        width: 100
      },
      {
        title: '操作',
        dataIndex: 'CanOperate',
        key: 'CanOperate',
        width: 80,
        render: (text, record) => {
          return text ? <span key="CanOperate" style={{ color: '#008FEA', cursor: 'pointer' }} onClick={this.removeTalentHandler.bind(this, record)}>移除</span> : '';
        }
      }
    ];
    if (this.props.isElink) {
      res.pop();
    }
    return res;
  }

  getTalentTableProps = () => {
    const { storeDbInfos } = this.state;
    return {
      className: 'table-module',
      size: 'small',
      dataSource: storeDbInfos,
      columns: this.getTalentColumns(),
      pagination: false,
      rowKey: 'StoreDbId',
      scroll: { y: 160 }
    };
  }

  getTalentPopupElement = () => {
    return (
      <div className="table-popup-wrapper talent-popup-wrapper">
        <div className="table-popup__arrow" ref={e => {
          this.arrowRef = e;
        }}
        />
        <AntdTable {...this.getTalentTableProps()} />
      </div>
    );
  }

  handleTalentCountVisibleChange = (visible) => {
    if (this.state.stroreDbCount <= 0) {
      return;
    }
    this.setState({ talentCountTableVisible: visible });
    this.props.onClickTalentHandler && this.props.onClickTalentHandler();
  }

  refresh = () => {
    window.location.reload();
  }

  getQueryString = (item) => {
    let svalue = location.href.match(new RegExp('[?&]' + item + '=([^&#]*)(&?)', 'i'));
    return svalue ? svalue[1] : svalue;
  }
  componentDidMount = () => {
    if(this.props.isElink){
      this.renderTagArea()
    }
  }
  renderTagArea = () => {
    if(this.state.tagList.length > 0 && !this.hasRenderedTag) {
      let tagWrapWidth = this.tagWrap.offsetWidth + 5
      let showTagWidth = 0
      let tagNum = 0
      if(this.props.isAddTag){
        showTagWidth += 34 // 添加标签按钮宽度
      }
      let tagDom = $('.tag-down .tag')
      for(let i=0;i< tagDom.length;i++){
        if((showTagWidth + tagDom[i].offsetWidth + 10) > tagWrapWidth){
          tagNum--
          if(showTagWidth + 24 > tagWrapWidth){
            tagNum--
          }
          this.hasRenderedTag = true
          this.setState({
            tagShowNum: tagNum,
          })
          return
        } else {
          showTagWidth += (tagDom[i].offsetWidth + 10)
          tagNum++
        }
      }
      this.hasRenderedTag = true
      this.setState({
        tagShowNum: this.state.tagList.length,
      })
    }
  }
  componentDidUpdate = () => {
    this.renderTagArea()
  }
  /* eslint complexity: 0 */
  render() {
    let proportionUrl = '';
    if (this.props.dataSource.assessmentSimilar || this.props.dataSource.connections) {
      // proportionUrl = '#applicants/newShow/ai?from=JobApplicantList&personId=' + this.getQueryString('personId') + '&jobId=' + this.getQueryString('jobId') + '&projectId=' + this.getQueryString('projectId');
      proportionUrl = '#applicants/newShow/ai?' + window.location.hash.split('?')[1]
    }
    // let currentJobInfo = this.jobList[this.jobActiveIndex];
    let thresholdText = '';
    let ApplyLockStateDetail = this.props.dataSource.ApplyLockStateDetail;
    if (ApplyLockStateDetail && ApplyLockStateDetail.JobName) {
      thresholdText = ApplyLockStateDetail.JobName + '（' + ApplyLockStateDetail.JobCode + '）';
    }
    return (
      <div className="header-container">
        <div className="header-inner">
          <div className="left-info">
            <div className="content-up">
              <div className="icon-group">
                {this.props.dataSource.isRepeat && <span className="icon isRepeat" onClick={this.onClickRepeat} />}
                {this.props.dataSource.isInterRec ? <span className="icon isInterRec">
                  {(this.props.dataSource.internalTips.length > 0 && this.props.isShowTip) && <div className="internal-tip"><span className="arrow"/><ul className="content">
                    {
                      this.props.dataSource.internalTips.map((internal, index) => {
                        return <li key={index} className="row"><span className="field">{internal['field']}</span><span>{internal['value']}</span></li>;
                      })
                    }
                  </ul></div>}
                </span> : null}
                {this.props.dataSource.isHunter ? <span className="icon isHunter">
                  {(this.props.dataSource.hunterTips.length > 0 && this.props.isShowTip) && <div className="hunter-tip"><span className="arrow"/><ul className="content">
                    {
                      this.props.dataSource.hunterTips.map((hunter, index) => {
                        return <li key={index} className="row"><span className="field">{hunter['field']}</span><span>{hunter['value']}</span></li>;
                      })
                    }
                  </ul></div>}
                </span> : null}
                {this.props.isNoContact &&
                  <span className="icon isNocontact">
                    <div className="nocontact-tip">
                      <span className="arrow"/>
                      <span className="">手机号，邮箱缺失</span>
                    </div>
                  </span>
                }
                {this.props.isExternalRec &&
                  <span className="icon isExternalRec"/>
                }
              </div>
              <div className="detail">
                <span className="name" title={this.props.dataSource.name}>{this.props.dataSource.name}</span>
                <span className="id">{this.props.dataSource.id}</span>
                <span className="job" onClick={this.onClickJobListHandler}>
                  <span className="job-title" title={this.jobList[this.jobActiveIndex]['jobTitle']}>{this.jobList[this.jobActiveIndex]['jobTitle']}</span>
                  {this.jobList.length > 1 && <span className="arrow-expand" ref={arrowIcon => this.arrowIcon = arrowIcon} />}
                  <ul className="joblist" ref={joblist => this.joblistDom = joblist}>
                    {
                      this.jobList.map((job, index) => {
                        return <li key={index} className={`jobli ${this.jobActiveIndex === index ? 'active' : ''}`} index={index} onClick={this.onClickJobHandler} title={job['jobTitle']}>{job['jobTitle']}</li>;
                      })
                    }
                  </ul>
                </span>
                {
                  this.jobList.length > 1 ? <Trigger
                    action={['click']}
                    builtinPlacements={placements}
                    popupClassName={'table-popup-container'}
                    popupPlacement={'bottom'}
                    popup={this.getJobPopupElement()}
                    popupVisible={this.state.jobCountTableVisible}
                    onPopupVisibleChange={this.handleJobCountVisibleChange}
                  ><span className="num" onClick={this.onClickJobNumHandler}>{this.props.dataSource.jobCount} 次应聘</span>
                  </Trigger> : null
                }
                {
                  this.state.stroreDbCount > 0 ? <Trigger
                    action={['click']}
                    builtinPlacements={placements}
                    popupClassName={'table-popup-container'}
                    popupPlacement={'bottom'}
                    popup={this.getTalentPopupElement()}
                    popupVisible={this.state.talentCountTableVisible}
                    onPopupVisibleChange={this.handleTalentCountVisibleChange}
                  ><span className="talent"><span className="talent-num">{`${this.state.stroreDbCount}`}</span>个人才库</span>
                  </Trigger> : null
                }
                <span className="repeat-resume-container">
                  {
                    this.props.dataSource.repeatResumesCount > 0 ?
                      <span className="check-repeat" onClick={this.props.showCheckRepeatData}>{ this.props.dataSource.repeatResumesCount }份重复简历</span>
                      : ''
                  }
                  <span className="keep-check-repeat" onClick={this.refresh}></span>
                </span>
              </div>
            </div>
            <div className="tag-down" ref={e => { this.tagWrap = e}}>
              {this.props.isAddTag && <span className={`addTag-btn ${!!!this.state.tagList.length && 'single'}`} onClick={this.addTagHandler} />}
              {
                this.state.tagList.slice(0, this.state.tagShowNum).map((tag, index) => {
                  return <span key={index} index={index} className={`tag type${tag['LabelType']} ${tag[this.props.isDeleteTagField] ? 'use' : 'disable'}`} onClick={this.deleteTagHandler}>
                    {tag['LabelName']}<span className="delIcon" />
                  </span>;
                })
              }
              {
                this.state.tagList.length > this.state.tagShowNum &&
                <span className="tag-more">
                  <div className="taglist">
                    {
                      this.state.tagList.slice(this.state.tagShowNum).map((tag, index) => {
                        return <span key={index} index={index + this.state.tagShowNum} className={`tag type${tag['LabelType']} ${tag[this.props.isDeleteTagField] ? 'use' : 'disable'}`} onClick={this.deleteTagHandler}>
                          {tag['LabelName']}<span className="delIcon" />
                        </span>;
                      })
                    }
                  </div>
                </span>
              }
              {!!!this.state.tagList.length && this.props.isAddTag && <span className="addTag-sub">添加标签，对应聘者快速分类</span>}
            </div>
          </div>
          <div className={`right-proportion${this.state.isShowRight ? '' : ' hidden'}`}>
            <div className="proportion"><div className="num">{`${Math.round(Number(this.props.dataSource.jobScore) * 100)}%`}</div><div className="sub">简历匹配度</div></div>
            {
              this.props.dataSource.assessmentSimilar ?
                <div className="proportion proportion_active"><a href={proportionUrl}><div className="num">{this.props.dataSource.assessmentSimilar}</div><div className="sub">相似人才</div></a></div>
                : <div className="proportion"><div className="num">{this.props.dataSource.assessmentSimilar}</div><div className="sub">相似人才</div></div>
            }
            {
              this.props.dataSource.connections ?
                <div className="proportion proportion_active"><a href={proportionUrl}><div className="num">{this.props.dataSource.connections}</div><div className="sub">人脉</div></a></div>
                : <div className="proportion"><div className="num">{this.props.dataSource.connections}</div><div className="sub">人脉</div></div>
            }
          </div>
          <div className="flag">
            {this.props.dataSource.threshold === 1 && <span className="threshold threshold-other"><div className="threshold-tip-wrapper"><div className="threshold-tip icon-tip" style={{ width: '255px', textAlign: 'left' }}><span className="arrow"/><span>此应聘者目前处于当前职位的门槛阶段，因此其他职位的申请仅允许淘汰，无法执行其他操作。<a href="/Recruiting/Desktop/Index#userguide?pageIndexKey=resumeApplicant&currentPage=2&currentIndex=0" target="_blank">点击了解</a>什么是门槛阶段</span></div></div></span>
            }
            {this.props.dataSource.threshold === 2 && <span className="threshold"><div className="threshold-tip-wrapper"><div className="threshold-tip icon-tip" style={{ width: '299px', textAlign: 'left' }}><span className="arrow"/>此应聘者目前在职位{thresholdText}下处于门槛阶段，因此当前职位仅允许淘汰，无法执行其他操作。<a href="/Recruiting/Desktop/Index#userguide?pageIndexKey=resumeApplicant&currentPage=2&currentIndex=0" target="_blank">点击了解</a>什么是门槛阶段</div></div></span>}
            {this.props.dataSource.lockState === 2 && <span className="lock" ><div className="lock-tip icon-tip"><span className="arrow"/>当前应聘者已被锁定</div></span>}
            {this.props.dataSource.lockState === 3 && <span className="lock lock-other" ><div className="lock-tip icon-tip"><span className="arrow"/>当前应聘者已被他人锁定</div></span>}
          </div>
        </div>
      </div>
    );
  }
}
