import * as React from 'react';
import Form from 'recruit-form';
import './index.scss';
import { getFormData } from './utils';

export default class ImportBasicInfoForm extends React.Component {

  static defaultProps = {
    dataSource: [],
    submitForm: () => {},
    setFormIsEdit: () => {}
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isSaveBtnDisabled: false
    };
    this.errorMessages = []
  }

  handleEdit = () => {
    this.setState({
      isEdit: true
    }, () => {
      this.form.handleExEdit();
      this.props.setFormIsEdit(true);
    });
  }

  submitForm = (data) => {
    this.setState({
      isEdit: false
    });
    this.props.submitForm(data);
  }

  formErrorNotify = (messageObj) => {
    let index
    let error = this.errorMessages.filter((error, point) => {
      if (error.field === messageObj.field) {
        index = point
        return error
      }
    })[0]
    if (messageObj.message) {
      error ? error.message = messageObj.message : this.errorMessages.push(messageObj)
    } else {
      if (error) this.errorMessages.splice(index, 1)
    }
    this.setState({
      isSaveBtnDisabled: this.errorMessages.length > 0
    });
  }

  handleBtnSave = () => {
    if (this.state.isSaveBtnDisabled) {
      return;
    }
    this.form.handleSubmit();
    this.props.setFormIsEdit(false);
  }

  handleBtnCancel = () => {
    this.setState({
      isEdit: false,
      isSaveBtnDisabled: false
    });
    this.form.handleExBack();
    this.props.setFormIsEdit(false);
  }
  componentDidMount = () => {
    let { MobileType, Mobile } = this.props.dataSource
    let chreg = /^1[3456789]\d{9}$/
    let othreg = /^\+?(00){1,2}(9[976]\d|8[987530]\d|6[987]\d|5[90]\d|42\d|3[875]\d|2[98654321]\d|9[8543210]|8[421]|6[6543210]|5[87654321]|4[987654310]|3[9643210]|2[70]|7|1)\d{1,14}$|^09\d{8,20}$/
    if ((MobileType == 'ch' && !chreg.test(Mobile)) || (MobileType == 'oth' && !othreg.test(Mobile))) {
      this.setState({
        isEdit: true
      }, () => {
        this.form.handleExEdit()
        this.form.triggerFormVerify()
      })
    }
  }

  render() {
    const { isEdit, isSaveBtnDisabled } = this.state;
    const saveClass = isSaveBtnDisabled ? ' disable' : '';
    const { dataSource = {}} = this.props;
    let _dataSource = getFormData(dataSource);
    return (
      <div className="import-basicinfo-content">
        <Form
          ref={ele => {
            this.form = ele;
          }}
          dataSource={_dataSource}
          formErrorNotify={this.formErrorNotify}
          submitForm={this.submitForm}
        />
        <div className="basicinfo-content__button-group">
          {
            isEdit ? <React.Fragment>
              <button className={'basicinfo-content__button save' + saveClass} onClick={this.handleBtnSave} >保存</button>
              <button className="basicinfo-content__button cancel" onClick={this.handleBtnCancel} >取消</button>
            </React.Fragment> : <button className="basicinfo-content__button edit" onClick={this.handleEdit}>编辑</button>
          }
        </div>
      </div>
    );
  }
}