const GenderValueDataSource = {
  0: '男',
  1: '女',
  2: '保密'
};

const GenderTextDataSource = {
  '男': 0,
  '女': 1,
  '保密': 2
};

export function getGenderTextFromValue(gender) {
  return GenderValueDataSource[gender];
}

export function getGenderValueFromText(gender) {
  return GenderTextDataSource[gender];
}

let eduValueDataSource;

export function getFormData(resp) {
  const genderText = getGenderTextFromValue(resp.Gender);
  if (!eduValueDataSource) {
    eduValueDataSource = {};
    for (let i in resp.eduDataSource) {
      eduValueDataSource[resp.eduDataSource[i]] = i;
    }
  }
  const eduDropDownOrder = ['小学', '初中', '高中', '中技（中专/技校/职高）', '大专', '本科', '硕士研究生', 'MBA', '博士研究生'];
  const eduDropdownData = eduDropDownOrder.map(i => {
    return {
      text: i,
      value: eduValueDataSource[i],
      selected: resp.EducationLevel.toString() === eduValueDataSource[i]
    };
  });
  let nameRules = [{ reg: 'empty', message: '姓名不能为空' }, {
    message: '最长30个字符',
    verifyFn: function (value) {
      if (value.length > 30) {
        return false;
      } else {
        return true;
      }
    }
  }];
  let chreg = /^1[3456789]\d{9}$/ // 大陆手机号
  let othreg = /^\+?(00){1,2}(9[976]\d|8[987530]\d|6[987]\d|5[90]\d|42\d|3[875]\d|2[98654321]\d|9[8543210]|8[421]|6[6543210]|5[87654321]|4[987654310]|3[9643210]|2[70]|7|1)\d{1,14}$|^09\d{8,20}$/ // 非大陆手机号
  let phoneRules = [{
    reg: 'phone',
    message: '请填写正确的手机',
    verifyFn: function (value, allData) {
      let phoneSel = allData.find((i) => i.filed === 'mobile')
      let reg = phoneSel.mobileType === 'ch' ?  chreg: othreg
      return reg.test(value);
    }
  }];
  if (resp.RequireNameAndMobile) {
    phoneRules.push({ reg: 'empty', message: '手机不能为空' });
  }
  let emailRules = resp.RequireEmail ? [{ reg: 'email', message: '请填写正确的邮箱' }, { reg: 'empty', message: '邮箱不能为空' }] : [{ reg: 'email', message: '请填写正确的邮箱' }];
  return [
    {
      filed: 'name',
      fieldName: '姓名',
      text: resp.Name,
      value: resp.Name,
      name: resp.Name,
      cmp_type: 'input',
      rule: nameRules
    },
    {
      filed: 'mobile',
      fieldName: '手机',
      text: resp.Mobile,
      value: resp.Mobile,
      mobile: resp.Mobile,
      cmp_type: 'input-phone',
      mobileType: resp.MobileType,
      rule: phoneRules
    },
    // {
    //   filed: 'mobile',
    //   fieldName: '',
    //   text: resp.Mobile,
    //   value: resp.Mobile,
    //   mobile: resp.Mobile,
    //   cmp_type: 'input',
    //   rule: phoneRules
    // },
    {
      filed: 'email',
      fieldName: '邮箱',
      text: resp.Email,
      value: resp.Email,
      email: resp.Email,
      cmp_type: 'input',
      rule: emailRules,
      title: resp.Email
    },
    {
      filed: 'gender',
      fieldName: '性别',
      text: genderText,
      value: resp.Gender,
      cmp_type: 'dropdown',
      biz_data: [
        {
          text: '男',
          value: 0,
          selected: genderText === '男'
        }, {
          text: '女',
          value: 1,
          selected: genderText === '女'
        }, {
          text: '保密',
          value: 2,
          selected: genderText === '保密'
        }
      ]
    },
    {
      filed: 'highestdegree',
      fieldName: '最高学历',
      text: resp.eduDataSource[resp.EducationLevel],
      value: resp.EducationLevel === 0 ? '' : resp.EducationLevel,
      cmp_type: 'dropdown',
      biz_data: eduDropdownData
    }
  ];
}