import React, { PureComponent } from 'react';
import './index.scss';
import { getWebUrl, addEventListenerWrap } from './utils';
import RelJob from './reljob';
import RelStore from './relstore';
import EmptyComponent from '@beisen/empty-component';

// const _ = window._;
export default class RepeatResume extends PureComponent {

  constructor(props) {
    super(props);
    this.state = {
      iframeHeight: 0,
      repeatResumePageSize: 1
    };
  }

  handlerIframeOnLoad = (e) => {
    if (this.props.HasPermisson) {
      // this.props.actions.fetchRepeatResumePageSize(this.props.PersonId);
      let url = '/Recruiting/ApplicantOverview/GetOfficeDocumentPageSize?personId=' + this.props.PersonId + '&jobId=0';
      const options = {
        headers: {
          'Accept': 'application/json, application/xml, text/play, text/html, *.*',
          'Content-Type': ' application/json; charset=utf-8',
          'x-beisen-ajax': 1.0,
          'X-Beisen-ts': new Date().getTime(),
          'x-referer': window.location.hash
        },
        credentials: 'same-origin',
        method: 'GET'
      };
      fetch(url, options).then(res => {
        if (res.ok) {
          return res.json();
        }
      }).then(data => {
        this.setState({
          repeatResumePageSize: data.data
        });
      });
    }
    try {
      const iframeNode = e.target;
      if (!iframeNode.contentDocument) {
        throw 'maybe cross origin, can`t calculate dom height';
      }
      const height = Math.max(iframeNode.contentDocument.body.scrollHeight, iframeNode.contentDocument.documentElement.scrollHeight, iframeNode.contentDocument.body.offsetHeight, iframeNode.contentDocument.documentElement.offsetHeight, iframeNode.contentDocument.body.clientHeight, iframeNode.contentDocument.documentElement.clientHeight);
      this.setState({
        iframeHeight: height + 20 // offset
      });
    } catch (error) {
      console.error(error);
    }

  }
  componentDidMount() {
    // const iframeDom = this.wrapper.getElementsByTagName('iframe');
    // if (iframeDom && iframeDom[0]) {
    //   this.iframeLoadEvent = addEventListenerWrap(iframeDom[0], 'load', this.handlerIframeOnLoad);
    // }
  }

  componentWillUnmount() {
    // this.iframeLoadEvent && this.iframeLoadEvent.remove();
  }

  render() {
    const { Name, Email, Mobile, Elink, IsBlacked, IsHunter, HasOrginalResume, HasPermisson, PersonId } = this.props;
    const { iframeHeight, repeatResumePageSize } = this.state;
    const iframeStyle = {
      'pointer-events': 'none',
      width: '100%',
      height: (1170 * repeatResumePageSize > iframeHeight ? 1170 * repeatResumePageSize : iframeHeight) + 'px'
    };
    let resumeUrl;
    let standardResume;
    if (this.props.ApplyInfo.length > 0) {
      resumeUrl = getWebUrl('Recruiting/ApplicantOverview/Snapshot') + '?personId=' + PersonId + '&RelId=' + this.props.ApplyInfo[0].ApplyId + '&notlowerDomain=true&isPrint=false&isLastResume=true';
      standardResume = getWebUrl('Recruiting/ApplicantOverview/OverviewResume') + '?personId=' + PersonId + '&RelId=' + this.props.ApplyInfo[0].ApplyId + '&isPrint=false&lockState=2&lan=zh_CN&r=' + _.random(100000000000);
    } else {
      resumeUrl = getWebUrl('Recruiting/ApplicantOverview/Snapshot') + '?personId=' + PersonId + '&RelId=0&notlowerDomain=true&isPrint=false&isLastResume=true';
      standardResume = getWebUrl('Recruiting/ApplicantOverview/OverviewResume') + '?personId=' + PersonId + '&RelId=0&isPrint=false&lockState=2&lan=zh_CN&r=' + _.random(100000000000);
    }
    let repeatDetailSrc = '/Recruiting/ApplicantOverview/ApplicantDetailInfo?personId=' + PersonId + '&authtoken=' + window.BSGlobal.authtoken + '&from=JobApplicantList&jobId=0#applicants/show?from=JobApplicantList&personId=' + PersonId + '&jobId=0';
    if (PersonId === 0) {
      return <EmptyComponent />;
    }
    return (
      <div className="repeat-resume-preview-wrapper" ref={(ele) => {this.wrapper = ele;}}>
        <div className="repeat-rules-tip">根据 <span><a href="/Recruiting/Desktop/Index#userguide?pageIndexKey=resumeApplicant&currentPage=1&currentIndex=0" target="_blank">查重规则</a></span> ，您导入的简历在系统中已有对应的应聘者，应聘者简历相关信息如下：</div>
        <section className="repeat-resume-detail">
          <span className="name">
            {
              IsHunter &&
              <i className="hunter-icon" />
            }
            {Name}
          </span>
          {
            !!Mobile &&
            <span className="tel">{Mobile}</span>
          }
          {
            !!Email &&
            <span className="email">{Email}</span>
          }
          {
            this.props.ApplyInfo.length > 0 && !IsBlacked &&
            <RelJob applyInfo={this.props.ApplyInfo} />
          }
          {
            this.props.RelatedStoreDbList.length > 0 && !IsBlacked &&
            <RelStore relStore={this.props.RelatedStoreDbList} />
          }
          {
            IsBlacked &&
            <span className="black">该应聘者已在黑名单中</span>
          }
          {/* todo: 展示最近一次申请的原始简历 || 标准简历 */}
          {
            HasPermisson &&
            <span className="fr"><a href={repeatDetailSrc} target="_blank">查看详情</a></span>
          }
        </section>
        <iframe src={HasOrginalResume ? resumeUrl : standardResume} />
      </div>
    );
  }
}

