import React, { PureComponent } from 'react';
import Trigger from 'rc-trigger';
import placements from './placements';
import AntdTable from 'antd/lib/table';

export default class RelJob extends PureComponent {
  getPopupElement = () => {
    return (
      <div className="table-popup-wrapper jobtips-popup-wrapper">
        <div className="table-popup__arrow" ref={e => {
          this.arrowRef = e;
        }}
        />
        <AntdTable {...this.getTableProps()} />
      </div>
    );
  }
  getColumns = () => {
    return [
      {
        title: '需求部门',
        dataIndex: 'DepartmentName',
        key: 'DepartmentName',
        width: 80,
        render: data => {
          return data || '-';
        }
      },
      {
        title: '申请职位',
        dataIndex: 'JobNameCode',
        key: 'JobNameCode',
        width: 120,
        render: record => {
          return [<div key="JobName">{record.JobName}</div>, <div key="JobCode">{record.JobCode}</div>
          ];
        }
      },
      {
        title: '阶段-状态',
        dataIndex: 'PhaseAndStatusName',
        key: 'PhaseAndStatusName',
        width: 110
      },
      {
        title: '申请时间',
        dataIndex: 'ApplyDate',
        key: 'ApplyDate',
        width: 90,
        render: ApplyDate => {
          return _.formatDate(ApplyDate);
        }
      },
      {
        title: '申请渠道',
        dataIndex: 'ChannelSouce',
        key: 'ChannelSouce',
        width: 100,
        render: data => {
          return data || '-';
        }
      }, {
        title: '职位负责人',
        dataIndex: 'HrDuty',
        key: 'HrDuty',
        width: 220,
        render: record => {
          return [<div key="PrincipalName">{record.PrincipalName}</div>, <div key="PrincipalEmail">{record.PrincipalEmail}</div>
          // <div key='PrincipalMobile'>{record.PrincipalMobile}</div>
          ];
        }
      }, {
        title: '职位状态',
        dataIndex: 'JobStatus',
        key: 'JobStatus',
        width: 100,
        render: data => {
          return data || '-';
        }
      }
    ];
  }
  formatTableData = (res) => {
    return res.map((i, index) => {
      return {
        ..._.omit(i, ['PhaseName', 'StateName']),
        PhaseAndStatusName: i.PhaseName + '-' + i.StateName,
        JobNameCode: {
          JobName: i.JobName,
          JobCode: i.JobCode
        },
        HrDuty: {
          PrincipalEmail: i.PrincipalEmail,
          // PrincipalMobile: i.PrincipalMobile,
          PrincipalName: i.PrincipalName
        }
      };
    });
  }
  getTableProps = () => {
    return {
      className: 'table-module',
      size: 'small',
      dataSource: this.formatTableData(this.props.applyInfo),
      columns: this.getColumns(),
      pagination: false,
      rowKey: 'ApplyId',
      scroll: { y: 160 }
    };
  }
  render() {
    return (
      <Trigger
        popupPlacement="bottom"
        action={['hover']}
        builtinPlacements={placements}
        popup={this.getPopupElement()}
        popupClassName={'rjc-popup-adjust'}
      >
        <span className="apply-info" key="rj">{this.props.applyInfo.length}次应聘</span>
      </Trigger>
    );
  }
}
