import React, { Component } from 'react';
import BaseComponent from '../BaseComponent';
import Node from '&/components/milestone/Node';
require('./index.scss');

/**
* milestone里程碑组件
* props：dataSource：元数据，数组结构
         stageField：父节点要显示值在页面上的字段名
         stateField：子节点要显示值在页面上的字段名
         stateListField：父节点内所子集合的字段名
         stageActiveField：判断父节点是否选中的字段名
         stateActiveField：判断子节点是否选中的字段名
         stageActive：被选中父节点的相应字段的value
         stateActive：被选中子节点的相应字段的value
*/
export default class extends BaseComponent {
    constructor(props) {
		super(props);
        this.arrowClick = this.arrowClick.bind(this);
        this.arrowMouseOver = this.arrowMouseOver.bind(this);
        this.arrowMouseOut = this.arrowMouseOut.bind(this);
        this.backActiveStage = this.backActiveStage.bind(this);

        this.state = {
            dataSource: []
        }
	}

    componentWillReceiveProps(nextProps) {
        this.props = nextProps
        this.formatMetaData(nextProps.dataSource);
    }

    componentWillMount() {
        this.formatMetaData(this.props.dataSource);
    }

    componentDidUpdate(prevProps, prevState) {
        this.componentDidMount()
    }

    componentDidMount() {
        //可以滚动的距离
        this.distances = this.scrollDom.offsetWidth - this.contentDom.offsetWidth;
        //可以滚动总页数
        this.pages = Math.abs(this.distances / this.contentDom.offsetWidth);
        //一页的长度
        this.pageLen = this.contentDom.offsetWidth;

        if(this.distances <= 0) {
            !!!this.refs.arrowL.className.match('disable') && (this.refs.arrowL.className = 'arrow-left disable')
            !!!this.refs.arrowR.className.match('disable') && (this.refs.arrowR.className = 'arrow-right disable')
        }

        if(this.activeStage && this.activeStage.left > this.pageLen) {
            const space = this.lastStage.left - this.activeStage.left;
            this.scrollDom.style.left = space > this.pageLen ? `-${this.activeStage.left}px` : `-${this.activeStage.left - (this.pageLen - (space + this.lastStage.width))}px`;
        }else {
            !!!this.refs.arrowL.className.match('disable') && (this.refs.arrowL.className = 'arrow-left disable')
        }
    }

    adjustArrowStatus() {
        //可以滚动的距离
        this.distances = this.scrollDom.offsetWidth - this.contentDom.offsetWidth;

        if(this.scrollDom && (Math.abs(parseInt(this.scrollDom.style.left)) <= 0)) {
            !this.refs.arrowL.className.match('disable') && (this.refs.arrowL.className = 'arrow-left disable')
        }else {
            this.refs.arrowL.className.match('disable') && (this.refs.arrowL.className = 'arrow-left')
        }
        if(this.scrollDom && Math.abs(parseInt(this.scrollDom.style.left)) >= this.distances) {
            !this.refs.arrowR.className.match('disable') && (this.refs.arrowR.className = 'arrow-right disable')
        }else {
            this.refs.arrowR.className.match('disable') && (this.refs.arrowR.className = 'arrow-right')
        }
    }
    /**
    * 子组件Stage返回选中的stage节点对象，里面包含此节点距离左侧的距离
    */
    backActiveStage(stage) {
        if(stage.type === 'active') {
            this.activeStage = stage;
        }else {
            this.lastStage = stage;
        }
    }
    /**
    * 格式化元数据，元数据必须是数组结构，将进行中的阶段和其子状态节点名称拼接
    */
    formatMetaData(metadata) {
      let dataSource = [];
      const phaseList = Object.prototype.toString.call(metadata) === '[object Array]' ? metadata : [];
      let activeIndex;
      phaseList.forEach((phase, index) => {
        let nodeObj = {}
        if(this.props.stageActive === phase[this.props.stageActiveField]) {
          activeIndex = index;
          const activeState = phase[this.props.stateListField].filter(state => {
            return this.props.stateActive === state[this.props.stateActiveField]
          })
          nodeObj.status = 'current'
          nodeObj.text = `${phase['PhaseName']}（${activeState.length > 0 ? activeState[0]['StatusName'] : ''}）`
        }else {
            if(activeIndex === undefined || index < activeIndex) {
              nodeObj.status = 'before'
            }else if(index > activeIndex) {
              nodeObj.status = 'later'
            }
            nodeObj.text = `${phase['PhaseName']}`
        }
        nodeObj.index = index
        dataSource.push(nodeObj)
      });
      this.setState({dataSource})
    }
    /**
    * 滚动按钮点击事件：点击一次滚动一页，不够一页滚动剩余部分
    */
    arrowClick(e) {
        if(this.distances <= 0) {
            return ;
        }
        //是否点击右侧按钮
        const isRight = e.target && e.target.className.match('right') && e.target.className.match('right').length > 0;
        //需要滚动元素left值
        const domLeft = Math.abs(parseInt(this.scrollDom.style.left || 0));
        //当前页数
        const page = domLeft / this.contentDom.offsetWidth;
        //执行滑动一页
        this.scrollDom.style.left = '-' + (isRight ? ((page + 1) >= this.pages ? Math.abs(this.distances + this.refs.arrowL.offsetWidth * 2) : (page + 1) * this.pageLen - this.refs.arrowL.offsetWidth * 2) : page - 1 <= 0 ? 0 : (page - 1) * this.pageLen) + 'px';

        const newDomLeft = Math.abs(parseInt(this.scrollDom.style.left || 0));
        this.adjustArrowStatus();
    }
    /**
    * 鼠标经过箭头时，箭头高亮
    */
    arrowMouseOver(e) {
        e.target.className = `${e.target.className.replace(/out/g,'')} over`;
    }
    /**
    * 鼠标离开箭头时，箭头还原
    */
    arrowMouseOut(e) {
        e.target.className = `${e.target.className.replace(/over/g,'')} out`;
    }

    render () {
      return (<div className='stage-container' ref={contentDom => {this.contentDom = contentDom}}>
                <div className='arrow-left'
                     ref='arrowL'
                     onClick={this.arrowClick}
                     onMouseOver={this.arrowMouseOver}
                     onMouseOut={this.arrowMouseOut}
                     />
                <div className='scroll-content'
                      ref={scroll => {this.scrollDom = scroll}}
                      >
                  {
                    this.state.dataSource.map((data, index) => {
                      return (
                        <div className='node-item' key={index}>
                          <Node key={index}
                                {...data}
                                isLast={(this.state.dataSource.length-1) === index}
                                backActiveStage={this.backActiveStage}
                                />
                        </div>
                      )
                    })
                  }
                </div>
                <div className='arrow-right'
                     ref='arrowR'
                     onClick={this.arrowClick}
                     onMouseOver={this.arrowMouseOver}
                     onMouseOut={this.arrowMouseOut}
                     />
    		  </div>);
    }
}
