import React, { Component } from 'react';
import * as Radio from 'antd/lib/radio';
import * as PropTypes from 'prop-types';
import 'antd/lib/radio/style/css';
import BaseComponent from '../BaseComponent';
import './index.scss';

export default class RadioButtons extends BaseComponent{
  static defaultProps = {
    buttonStyle: 'solid',
    radioStyle: {},
    label: '',
    emptyText: '',
    sources: [], // key value格式
    defaultValue: null
  };

  constructor(props) {
    super(props);
    this.state = {};
    this.baseStyle = {
      marginRight: '10px',
      fontSize: '14px',
      fontWeight: 'normal',
      borderRadius: '3px'
    };
    this.onChange = this.onChange.bind(this);
  }

  onChange(e) {
    if (!!this.props.onChange && this.props.onChange instanceof Function) {
      this.props.onChange(e);
    }
  }

  render() {
    const { sources, radioStyle, label, defaultValue, buttonStyle, emptyText } = this.props;
    const style = Object.assign({}, this.baseStyle, radioStyle);
    return (
      <div className="bs-radio-buttons">
        {!!label ? <span className="bs-radio-buttons__label">{label}：</span> : null}
        {sources.length > 0 ? (
          <Radio.Group
            onChange={this.onChange}
            defaultValue={defaultValue}
            buttonStyle={buttonStyle}
            className="bs-radio-buttons__radio-group">
            {sources.map((itm) => (
              <Radio.Button
                style={style}
                key={typeof itm.value === 'string' ? itm.value : JSON.stringify(itm)}
                value={itm.value}>{itm.key}</Radio.Button>))
            }
          </Radio.Group>) : (
          <span className="bs-radio-buttons__empty">{emptyText}</span>
        )}
      </div>
    );
  }
}
RadioButtons.propTypes = {
  buttonStyle: PropTypes.string,
  radioStyle: PropTypes.object,
  label: PropTypes.string,
  sources: PropTypes.array,
  defaultValue: PropTypes.any,
  emptyText: PropTypes.string
};
