import * as React from 'react';
import AntdTable from 'antd/lib/table';
import { addEventListenerWrap } from './utils';
import EmptyComponent from '@beisen/empty-component';

import 'antd/lib/tabs/style/css';
import 'antd/lib/checkbox/style/css';
import 'antd/lib/modal/style/css';
import './index.scss'
export default class RequirementContent extends React.Component {

  static defaultProps = {
    placeholder: '请输入',
    multiple: false,
    notNeedScrollFetch: false
  }

  constructor(props) {
    super(props);
    this.state = {
      isLoading: false,
      tableData: []
    };
    this.pageIndex = 1;
    this.pageCount = null;
  }

  getColumns = () => {
    return [
      {
        title: '需求名称',
        dataIndex: 'Name',
        key: 'Name',
        width: 120,
        render: (record, data, index)=> {
          if (!record) {
            return '-';
          }
          return record;
        }
      },
      {
        title: ' 需求部门',
        dataIndex: 'DepartmentName',
        key: 'DepartmentName',
        width: 140,
        render: (record, data, index) => {
          if (!record) {
            return '-';
          }
          return record;
        }
      },
      {
        title: '需求人数',
        dataIndex: 'RequirementCount',
        key: 'RequirementCount',
        width: 130,
        render: (record, data, index) => {
          if (!record) {
            return '-';
          }
          return record;
        }
      },
      {
        title: '已到岗人数',
        dataIndex: 'ArivalCount',
        key: 'ArivalCount',
        width: 140,
        render: (record, data, index) => {
          if (!record) {
            return '-';
          }
          return record;
        }
      },
      {
        title: '需求提出时间',
        dataIndex: 'CreateDate',
        key: 'CreateDate',
        width: 160,
        render: (record, data, index) => {
          if (!record) {
            return '-';
          }
          return _.formatDate(record);
        }
      },
      {
        title: '期望到岗时间',
        dataIndex: 'ArivalTime',
        key: 'ArivalTime',
        width: 160,
        render: (record, data, index) => {
          if (!record) {
            return '-';
          }
          return  _.formatDate(record);
        }
      },{
        title: '需求负责人',
        dataIndex: 'DutyUserName',
        key: 'DutyUserName',
        width: 160,
        render: (record, data, index) => {
          if (!record) {
            return '-';
          }
          return record;
        }
      }
    ];
  }

  formatTableData = (data = []) => {
    return data.map((i, index) => {
      return {
        ...i,
        key: i.RecruitRequirementGuid
      }
    })
  }

  // 处理行操作 checkbox勾选回调
  rowSelection = () => {
    const { multiple, selected } = this.props;
    let selectedRowKeys = [];
    selected.length && selected.forEach(i => {
      selectedRowKeys.push(i.key)
    });
    let rowSelection = {
      type: multiple ? 'checkbox' : 'radio',
      fixed: false,
      columnTitle: '',
      onChange: this.handleSelectOnChange,
      selectedRowKeys: selectedRowKeys,
      columnWidth: 50
    }
    return rowSelection
  }

  // checkbox改变 回调
  handleSelectOnChange = (selectedRowKeys, selectedRows) => {
    if (!this.props.multiple) {
      this.props.handleTableSelected(selectedRows);
      return;
    }
  }

  getTableProps = () => {
    const { isLoading, tableData } = this.state;
    return {
      className: 'table-module',
      size: 'small',
      loading: isLoading,
      dataSource: this.formatTableData(tableData),
      columns: this.getColumns(),
      rowSelection: this.rowSelection(),
      pagination: false,
      scroll: { y: 150 },
      locale: { emptyText: <EmptyComponent />, sortTitle: '' }
    };
  }

  getTableUrl = () => {
    const {tenantId, fromJobId} = this.props
    return '/Recruiting/ApplicantProcess/GetRequirementListByJobId?jobId=' + fromJobId.toString() + '&tenantId=' + tenantId;
  }

  fetchTableData = () => {
    this.setState({
      isLoading: true
    });
    const url = this.getTableUrl();
    const options = {
      headers: {
        'Accept': 'application/json, application/xml, text/play, text/html, *.*',
        'Content-Type':' application/json; charset=utf-8',
        // 'Content-Type': 'application/x-www-form-urlencoded',
        'x-beisen-ajax': 1.0,
        'X-Beisen-ts': new Date().getTime(),
        'x-referer': window.location.hash
      },
      credentials: 'same-origin',
      method: 'get'
    };
    fetch(url, options).then(res => {
      if (res.ok) {
        return res.json()
      }
    }).then(data => {
      if (data.code === 200) {
        this.setState({
          isLoading: false,
          tableData: data.data
        }, ()=> {
          if (this.props.notNeedScrollFetch) {
            return;
          }
          if (this.tableListener) {
            return;
          }
          this.tableListener = true;
        });
      }
    })
  }

  componentDidMount() {
    this.fetchTableData();
  }

  render() {
    return (
      <div className='popup-content applicant-detail_requirement-content' style={{height: '235px'}}>
        <div className='popup-table-content' ref={ele => {this.tableWrapper = ele;}}>
          <AntdTable {...this.getTableProps()} />
        </div>
      </div>
    )
  }
}
