import * as React from "react";
import Modal from "antd/lib/modal";
import IframeContent from "./iframe-content";
import Notice from "ux-tms-notice";
import {
  getTenantInfo,
  getUserInfo,
  getQueryObj
} from "../../../src/helper/index";

import "antd/lib/modal/style/css";
const { _, $ } = window;

export default class ThirdPartIframe extends React.Component {
  static defaultProps = {
    title: "发起i背调"
  };

  constructor(props) {
    super(props);
    this.state = {
      visible: true
    };
  }

  // 获取iframe参数
  getIframePostData = opt => {
    const ajaxData = {};
    const _ = window._;
    const metaData = opt.btnConfig.metaData;
    const requires = metaData.Requires;

    const hasToken = _.contains(requires, "token");
    if (hasToken) {
      ajaxData.token = metaData["Token"];
    }

    const hasPersonId = _.contains(requires, "personId");
    if (hasPersonId) {
      ajaxData.personId = opt.context.personIds.join();
    }
    const hasJobId = _.contains(requires, "jobId");

    // url中不存在jobid的时候，从context中读jobId
    if (hasJobId) {
      // Talent.app.request('history:getQueryObject').done(function (obj) {
      //   ajaxData.jobId = obj.jobId ? obj.jobId : opt.context.jobId.join()
      // })
      const hash = getQueryObj();
      ajaxData.jobId = hash.jobId ? hash.jobId : opt.context.jobId.join();
      // 兼容流程下全部应聘者时job为-1
      if (ajaxData.jobId === "-1") {
        ajaxData.jobId = opt.context.jobId.join();
      }
    }

    const hasTenantId = _.contains(requires, "tenantId");
    if (hasTenantId) {
      ajaxData.tenantId = getTenantInfo().id;
    }

    const hasUserId = _.contains(requires, "userId");
    if (hasUserId) {
      ajaxData.userId = getUserInfo().id;
    }
    return ajaxData;
  };

  // iframeUrl拼接
  handleIframeUrl = opt => {
    let ajaxData = this.getIframePostData(opt);
    let metaData = opt.btnConfig.metaData;
    let context = opt.context;

    let urlParams =
      metaData.AppCode !== "iBeidiao"
        ? Object.assign({}, ajaxData, {})
        : Object.assign({}, ajaxData, {
            req_AppCode: metaData.AppCode,
            req_email: context.email || "",
            req_mobile: context.mobile || "",
            req_personName: context.name || "",
            req_personId: ajaxData.personId,
            req_tenantId: ajaxData.tenantId,
            req_applyId: context["applyId"][0],
            req_jobId: ajaxData.jobId,
            req_userId: ajaxData.userId,
            req_SurveyCompanyName: context.companyList,
            iframeHeight: 500
          });

    let iframeUrl = metaData["Url"];
    let urlParamsArr = [];
    for (let key in urlParams) {
      let val = urlParams[key];
      urlParamsArr.push(key + "=" + val);
    }
    let urlParamsStr =
      (iframeUrl && iframeUrl.indexOf("?") > -1 ? "&" : "?") +
      urlParamsArr.join("&");

    let iframeObj = {
      height: parseInt(metaData["DialogHeight"]),
      width: parseInt(metaData["DialogWidth"]),
      url: iframeUrl + urlParamsStr,
      AppCode: metaData.AppCode
    };

    return iframeObj;
  };

  closeModal = data => {
    if (!data || (data.currentTarget && data.currentTarget.classList.contains('ant-modal-close'))) {  // 取消或 点击右上角关闭
      this.setState({ visible: false });
      this.props.onClick(); // 卸载dom
    } else {
      let { status, tipsShowCnt } = data.noticeInfo;
      if (status === "success") {
        Notice.success("", tipsShowCnt, 3000, () => {}, {
          top: "0px",
          zIndex: 10001
        });
        this.setState({ visible: false });
        this.props.onClick(); // 卸载dom
        setTimeout(() => {
         location.reload();
        }, 4000)
      }
      if (status === "error") {
        Notice.error("", tipsShowCnt, 3000, () => {}, {
          top: "0px",
          zIndex: 10001
        });
      }
    }
  };

  render() {
    const title = this.props.payload.btnConfig.metaData.Title
    const { visible } = this.state;
    const iframeObj = this.handleIframeUrl(this.props.payload);

    const cls = "thirdPartIframe thirdPart" + iframeObj.AppCode;
    return (
      <Modal
        visible={visible}
        title={title}
        maskClosable={false}
        width={iframeObj.width + 48}
        className={cls}
        centered={true}
        zIndex={9999}
        footer={null}
        onCancel={this.closeModal}
      >
        <IframeContent params={iframeObj} closeModal={this.closeModal} />
      </Modal>
    );
  }
}
