
import format from './stardand-metadata-format'
import flow from './event-flow'
import bEvents from './metadata/bind-events'
import rComponent from './metadata/render-component'
import * as utils from './metadata/utils'

/* 格式化pagebuild生成的元数据到标准运行态元数据函数 */
export let metadataFormat = format

/* 操作标准元数据的功能性函数 */
export let metadataUtil = utils

/*
* 外部可以直接使用的没有bindEvents功能的renderComponent
* 如果需要bingEvents功能，需要先install
*/
export let renderComponent = rComponent()

/*
* 外部可以直接调用bindEvents
* 没有传入任何dispatcher，所以不可以用，需要先install
*/
export let bindEvents = bEvents()


let isInstalled = false

/* 原数据解析模块初始化入口 */
export const install = ({ dispatcher, Vuex }) => {
  /* 第二次初始化，直接返回上次实例 */
  if (isInstalled) return

  /* 注册Vue事件流机制 */
  if (Vuex) flow(Vuex)
  
  /*
  * 如果传入了dispatcher，则配置bindEvents
  * 没有传入dispatcher，则直接返回renderComponent函数
  */
  if (dispatcher) {
    bindEvents = bEvents(dispatcher)
    renderComponent = rComponent(bindEvents)  
  }
  
  isInstalled = true
  
  return {
    bindEvents,
    renderComponent
  }
}
