
export function findCmpByConditions (cmps, conditions) {
  if (!Array.isArray(cmps)) cmps = [cmps]
  for (let cmp of cmps) {
    // 条件判断查找
    let findFlag = true
    let conKeys = Object.keys(conditions)
    for (let key of conKeys) {
      if (cmp[key] !== conditions[key]) {
        findFlag = false
        break
      }
    }
    if (findFlag) return cmp
    // 递归开始
    let { children = [] } = cmp
    if (children.length) {
      let _cmp = findCmpByConditions(children, conditions)
      if (_cmp) return _cmp
    }
  }
  return null
}

export function getChildren (cmps = []) {
  if (!Array.isArray(cmps)) cmps = [cmps]
  let children = []
  for (let cmp of cmps) {
    let { children: clds = [] } = cmp
    children = children.concat(clds)
  }
  return children
}

export function getDeepChildren (cmps = []) {
  if (!Array.isArray(cmps)) cmps = [cmps]
  let children = []
  for (let cmp of cmps) {
    let { children: clds = [] } = cmp
    children = children.concat(clds)
    if (clds.length) {
      children = children.concat(getDeepChildren(clds))
    }
  }
  return children
}

export function findByCmpName (cmps, cmpName) {
  return findCmpByConditions(cmps, { name: cmpName })
}

export function findCmpsByType (cmps, cmpType) {
  return getDeepChildren(cmps).filter(child => child.type === cmpType)
}

export function visitEveryCmp (cmps, cmpHandler = () => {}) {
  if (!Array.isArray(cmps)) cmps = [cmps]
  let cmpsHasSub = []
  function walkTheEndCmps (cmps) {
    for (let cmp of cmps) {
      let { children = [] } = cmp
      if (children.length) {
        cmpsHasSub.push(cmp)
        walkTheEndCmps(children)
      } else {
        cmpHandler(cmp)
      }
    }
  }
  walkTheEndCmps(cmps)
  for (let cmp of cmpsHasSub) {
    cmpHandler(cmp)
  }
}
